@@ -12,8 +12,9 @@ import token
 import tokenize
 from optparse import OptionParser
 from subprocess import Popen, PIPE
+from difflib import unified_diff
 
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
 
 pep8bin = 'pep8'
@@ -45,6 +46,7 @@ class FixPEP8(object):
     def __init__(self, filename, options):
         self.filename = filename
         self.source = open(filename).readlines()
+        self.original_source = copy.copy(self.source)
         self.newline = self._find_newline(self.source)
         self.results = []
         self.options = options
@@ -143,6 +145,20 @@ class FixPEP8(object):
     def fix_e211(self, result):
         self._fix_whitespace(result, r"( \()", "(")
 
+    def fix_e225(self, result):
+        target = self.source[result['line'] - 1]
+        offset = result['column']
+        fixed = ""
+        if target[offset - 2] not in tokenize.Whitespace:
+            fixed = target[:offset - 1] + " " + target[offset - 1]
+        else:
+            fixed = target[:offset - 1]
+        if target[offset] not in tokenize.Whitespace:
+            fixed += " " + target[offset:]
+        else:
+            fixed += target[offset:]
+        self.source[result['line'] - 1] = fixed
+
     def fix_e231(self, result):
         target = self.source[result['line'] - 1]
         fixed = ""
@@ -194,7 +210,7 @@ class FixPEP8(object):
         self.source[result['line'] - 1] = fixed
 
     def fix_w291(self, result):
-        fixed_line = self.source[result['line'] - 1].strip()
+        fixed_line = self.source[result['line'] - 1].rstrip()
         self.source[result['line'] - 1] = "%s%s" % (fixed_line, self.newline)
 
     def fix_w293(self, result):
@@ -204,13 +220,15 @@ class FixPEP8(object):
         source = copy.copy(self.source)
         source.reverse()
         found_notblank = False
+        blank_count = 0
         for cnt, line in enumerate(source):
             if re.match("^$", line):
-                source[cnt] = ''
+                blank_count += 1
+            else:
                 found_notblank = True
             if found_notblank and not re.match("^$", line):
-                source[cnt] = line.rstrip()
                 break
+        source = source[blank_count:]
         source.reverse()
         self.source = source
 
@@ -218,18 +236,32 @@ class FixPEP8(object):
         pass
 
 
+def _get_difftext(old, new):
+    diff = unified_diff(old, new, 'oiginal', 'fixed')
+    difftext = [line for line in diff]
+    return "".join(difftext)
+
+
 def main():
     """tool main"""
     parser = OptionParser(version="autopep8: %s" % __version__,
                           description=__doc__)
     parser.add_option('-v', '--verbose', action='store_true', dest='verbose',
                       help='print to verbose result.')
+    parser.add_option('-d', '--diff', action='store_true', dest='diff',
+                      help='diff print of fixed source.')
     opts, args = parser.parse_args()
     if not len(args):
         print parser.format_help()
         return 1
     fix = FixPEP8(args[0], opts)
-    print fix.fix(),
+    fixed_source = fix.fix()
+    if opts.diff:
+        new = StringIO("".join(fix.source))
+        new = new.readlines()
+        print _get_difftext(fix.original_source, new),
+    else:
+        print fixed_source,
 
 if __name__ == '__main__':
     main()
